=== modified file 'bzrlib/option.py'
--- bzrlib/option.py	2011-01-14 05:14:04 +0000
+++ bzrlib/option.py	2011-06-01 07:01:17 +0000
@@ -312,7 +312,7 @@
 
     def __init__(self, name, help, registry=None, converter=None,
         value_switches=False, title=None, enum_switch=True,
-        lazy_registry=None, short_name=None):
+        lazy_registry=None, short_name=None, short_value_switches=None):
         """
         Constructor.
 
@@ -328,6 +328,8 @@
             which takes a value.
         :param lazy_registry: A tuple of (module name, attribute name) for a
             registry to be lazily loaded.
+        :param short_name: The short name for the enum switch, if any
+        :param short_value_switches: A dict mapping values to short names
         """
         Option.__init__(self, name, help, type=self.convert, short_name=short_name)
         self._registry = registry
@@ -344,6 +346,7 @@
         self.converter = converter
         self.value_switches = value_switches
         self.enum_switch = enum_switch
+        self.short_value_switches = short_value_switches
         self.title = title
         if self.title is None:
             self.title = name
@@ -387,6 +390,10 @@
                     help = optparse.SUPPRESS_HELP
                 else:
                     help = self.registry.get_help(key)
+                if (self.short_value_switches and
+                    key in self.short_value_switches):
+                    option_strings.append('-%s' %
+                                          self.short_value_switches[key])
                 parser.add_option(action='callback',
                               callback=self._optparse_value_callback(key),
                                   help=help,
@@ -555,7 +562,8 @@
 _global_option('update')
 _global_registry_option('log-format', "Use specified log format.",
                         lazy_registry=('bzrlib.log', 'log_formatter_registry'),
-                        value_switches=True, title='Log format')
+                        value_switches=True, title='Log format',
+                        short_value_switches={'short': 's'})
 _global_option('long', help='Use detailed log format. Same as --log-format long',
                short_name='l')
 _global_option('short', help='Use moderately short log format. Same as --log-format short')

=== modified file 'bzrlib/tests/test_options.py'
--- bzrlib/tests/test_options.py	2011-01-19 18:40:15 +0000
+++ bzrlib/tests/test_options.py	2011-06-01 07:01:17 +0000
@@ -22,6 +22,7 @@
     controldir,
     errors,
     option,
+    registry,
     )
 from bzrlib.builtins import cmd_commit
 from bzrlib.commands import parse_args
@@ -412,6 +413,17 @@
         self.assertEqual('suggest lottery numbers', my_opt.help)
         self.assertEqual(orig_help, the_opt.help)
 
+    def test_short_value_switches(self):
+        reg = registry.Registry()
+        reg.register('short', 'ShortChoice')
+        reg.register('long', 'LongChoice')
+        ropt = option.RegistryOption('choice', '', reg, value_switches=True,
+            short_value_switches={'short': 's'})
+        opts, args = parse([ropt], ['--short'])
+        self.assertEqual('ShortChoice', opts.choice)
+        opts, args = parse([ropt], ['-s'])
+        self.assertEqual('ShortChoice', opts.choice)
+
 
 class TestVerboseQuietLinkage(TestCase):
 

